Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CopyFileSystem ¶
func CopyFileSystem(src fs.FS, dst filesystem.FileSystem) error
CopyFileSystem copies files from a source fs.FS to a destination filesystem.FileSystem, preserving structure and contents.
func CopyPartitionRaw ¶
CopyPartitionRaw copies raw data from one partition to another and verifies the copy.
Types ¶
type LimitedWriter ¶
LimitedWriter writes to W but limits the total amount of data written to N bytes. Each call to Write updates N to reflect the new amount remaining.
Click to show internal directories.
Click to hide internal directories.